@@ -134,6 +134,9 @@ enum {
 static void
 stop_passwd (PasswordDialog *pdialog);
 
+static void
+child_watch_remove (PasswordDialog *pdialog);
+
 static void
 free_passwd_resources (PasswordDialog *pdialog);
 
@@ -270,18 +273,34 @@ stop_passwd (PasswordDialog *pdialog)
 	 * If we return this way we can safely kill passwd as it has completed
 	 * its task.
 	 * 
-	 * Maybe we should run free_passwd_resources here first, and not let
-	 * our child watcher do it?
+	 * We must run free_passwd_resources here and not let our child
+	 * watcher do it, since it will access invalid memory after the
+	 * dialog has been closed and cleaned up.
 	 */
 	
 	if (pdialog->backend_pid != -1) {
+		child_watch_remove (pdialog);
 		kill (pdialog->backend_pid, 9);
+		free_passwd_resources (pdialog);
 	}
 	
 	/* Our child_watch_cb should now handle our kill signal,
 	 * run waitpid and call free_passwd_resources appropriately. */
 }
 
+/* Remove the child watcher only */
+static void
+child_watch_remove (PasswordDialog *pdialog)
+{
+	/* Remove IO watcher */
+	if (pdialog->backend_stdout_watch_id != 0) {
+		
+		g_source_remove (pdialog->backend_stdout_watch_id);
+		
+		pdialog->backend_stdout_watch_id = 0;
+	}
+}
+
 /* Clean up passwd resources */
 static void
 free_passwd_resources (PasswordDialog *pdialog)
@@ -315,13 +334,7 @@ free_passwd_resources (PasswordDialog *pdialog)
 		pdialog->backend_stdout = NULL;
 	}
 	
-	/* Remove IO watcher */
-	if (pdialog->backend_stdout_watch_id != 0) {
-		
-		g_source_remove (pdialog->backend_stdout_watch_id);
-		
-		pdialog->backend_stdout_watch_id = 0;
-	}
+	child_watch_remove (pdialog);
 	
 	/* Close PID */
 	if (pdialog->backend_pid != -1) {
@@ -738,7 +751,7 @@ passdlg_set_auth_state (PasswordDialog *pdialog, gboolean state)
 		gtk_widget_grab_focus (GTK_WIDGET (pdialog->new_password));
 		
 		/* Set open lock image */
-		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_DATA_DIR "/pixmaps/gnome-about-me-lock-open.png");
+		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_PIXMAP_DIR "/gnome-about-me-lock-open.png");
 	} else {
 		/* Not authenticated state */
 		
@@ -746,7 +759,7 @@ passdlg_set_auth_state (PasswordDialog *pdialog, gboolean state)
 		gtk_widget_grab_focus (GTK_WIDGET (pdialog->current_password));
 		
 		/* Set closed lock image */
-		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_DATA_DIR "/pixmaps/gnome-about-me-lock.png");
+		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_PIXMAP_DIR "/gnome-about-me-lock.png");
 	}
 }
 
@@ -833,7 +846,6 @@ passdlg_validate_passwords (PasswordDialog *pdialog)
 	GladeXML		*dialog;
 	const gchar	*new_password, *retyped_password;
 	glong			nlen, rlen;
-	gboolean 		valid = FALSE;
 	
 	dialog = pdialog->xml;
 	
@@ -984,7 +996,7 @@ passdlg_init (PasswordDialog *pdialog, GtkWindow *parent)
 	GtkAccelGroup	*group;
 	
 	/* Initialize dialog */
-	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-about-me.glade", "change-password", NULL);
+	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/gnome-about-me.glade", "change-password", NULL);
 	pdialog->xml = dialog;
 	
 	wpassdlg = WID ("change-password");
@@ -1094,5 +1106,6 @@ gnome_about_me_password (GtkWindow *parent)
 	stop_passwd (pdialog);
 	gtk_widget_destroy (wpassdlg);
 	g_queue_free (pdialog->backend_stdin_queue);
+	g_object_unref (dialog);
 	g_free (pdialog);
 }
